==> nextcloud-18.0.4.tar.bz2: nextcloud/lib/l10n/pt_PT.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Não é possível gravar no directório \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Isto normalmente pode ser resolvido, dando ao servidor da Web direitos de gravação para a diretoria de configuração",
    "See %s" : "Ver %s",
    "Sample configuration detected" : "Detetado exemplo de configuração",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Foi detectado que a configuração de amostra foi copiada. Isso pode danificar a sua instalação e não é suportado. Por favor, leia a documentação antes de realizar mudanças no config.php",
    "%1$s and %2$s" : "%1$s e %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s e %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s e %5$s",
    "Education Edition" : "Edição Educação",
    "Enterprise bundle" : "Pacote Empresa",
    "Groupware bundle" : "Pacote Colaborativo",
    "Social sharing bundle" : "Pacote Partilha Social",
    "PHP %s or higher is required." : "Necessário PHP %s ou superior.",
    "PHP with a version lower than %s is required." : "É necessário um PHP com uma versão inferir a %s.",
    "%sbit or higher PHP required." : "Necessário PHP %sbit ou superior.",
    "Following databases are supported: %s" : "São suportadas as seguintes bases de dados: %s",
    "The command line tool %s could not be found" : "Não foi encontrada a ferramenta de linha de comando %s",
    "The library %s is not available." : "A biblioteca %s não está disponível.",
    "Following platforms are supported: %s" : "São suportadas as seguintes plataformas: %s",
    "Server version %s or higher is required." : "É necessária versão do servidor %s or superior. ",
    "Server version %s or lower is required." : "É necessária versão do servidor %s or inferior.",
    "Authentication" : "Autenticação",
    "Unknown filetype" : "Tipo de ficheiro desconhecido",
    "Invalid image" : "Imagem inválida",
    "Avatar image is not square" : "A imagem do avatar não é quadrada.",
    "today" : "hoje",
    "tomorrow" : "Amanhã",
    "yesterday" : "ontem",
    "_in %n day_::_in %n days_" : ["em %n dia","em %n dias"],
    "_%n day ago_::_%n days ago_" : ["%n dia atrás","%n dias atrás"],
    "next month" : "Próximo mês",
    "last month" : "ultimo mês",
    "_in %n month_::_in %n months_" : ["em %n mês","em %n meses"],
    "_%n month ago_::_%n months ago_" : ["%n mês atrás","%n meses atrás"],
    "next year" : "Próximo ano",
    "last year" : "ano passado",
    "_in %n year_::_in %n years_" : ["dentro de%n ano","dentro de%n anos"],
    "_%n year ago_::_%n years ago_" : ["%n ano atrás","%n anos atrás"],
    "_in %n hour_::_in %n hours_" : ["dentro de %n hora","dentro de %n horas"],
    "_%n hour ago_::_%n hours ago_" : ["%n hora atrás","%n horas atrás"],
    "_in %n minute_::_in %n minutes_" : ["dentro de %n minuto","dentro de %n minutos"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minuto atrás","%n minutos atrás"],
    "in a few seconds" : "em breves segundos",
    "seconds ago" : "Minutos atrás",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Módulo com ID: %s não existe. Por favor active-o nas definições da aplicação ou contacte o administrador.",
    "File name is a reserved word" : "Nome de ficheiro é uma palavra reservada",
    "File name contains at least one invalid character" : "Nome de ficheiro contém pelo menos um caráter inválido",
    "File name is too long" : "Nome do ficheiro demasiado longo",
    "Dot files are not allowed" : "Ficheiros dot não são permitidos",
    "Empty filename is not allowed" : "Não é permitido um ficheiro sem nome",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "A app \"%s\" não pode ser instalada porque o ficheiro appinfo não pode ser lido.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "A aplicação \"%s\" não pode ser instada porque não é compatível com esta versão do servidor.",
    "__language_name__" : "Português",
    "This is an automatically sent email, please do not reply." : "Este e-mail foi enviado automaticamente, por favor não responda a este e-mail.",
    "Help" : "Ajuda",
    "Apps" : "Apps",
    "Settings" : "Definições",
    "Log out" : "Sair",
    "Users" : "Utilizadores",
    "Unknown user" : "Utilizador desconhecido",
    "Additional settings" : "Definições adicionais",
    "%s enter the database username and name." : "%s introduza o nome de utilizador da base de dados e o nome da base de dados.",
    "%s enter the database username." : "%s introduza o nome de utilizador da base de dados",
    "%s enter the database name." : "%s introduza o nome da base de dados",
    "%s you may not use dots in the database name" : "%s não é permitido utilizar pontos (.) no nome da base de dados",
    "You need to enter details of an existing account." : "Precisa de introduzir detalhes de uma conta existente.",
    "Oracle connection could not be established" : "Não foi possível estabelecer a ligação Oracle",
    "Oracle username and/or password not valid" : "Nome de utilizador/palavra-passe do Oracle inválidos",
    "PostgreSQL username and/or password not valid" : "Nome de utilizador/password do PostgreSQL inválidos",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Esta plataforma não suporta o sistema operativo Mac OS X e o %s poderá não funcionar correctamente. Utilize por sua conta e risco.",
    "For the best results, please consider using a GNU/Linux server instead." : "Para um melhor resultado, utilize antes o servidor GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Parece que a instância %s está a ser executada num ambiente PHP de 32-bits e o open_basedir foi configurado no php.ini. Isto levará a problemas com ficheiros de tamanho superior a 4 GB e é altamente desencorajado.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, remova a definição open_basedir do seu php.ini ou altere o seu PHP para 64-bits.",
    "Set an admin username." : "Definir um nome de utilizador de administrador",
    "Set an admin password." : "Definia uma palavra-passe de administrador.",
    "Can't create or write into the data directory %s" : "Não é possível criar ou escrever a directoria data %s",
    "Invalid Federated Cloud ID" : "Id. de Nuvem Federada Inválida",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Ao partilhar a interface %s deve implementar a interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "Não foi encontrada a partilha da interface %s",
    "Sharing backend for %s not found" : "Não foi encontrada a partilha da interface para %s",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s partilhado »%2$s« consigo e quer adicionar:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s partilhado »%2$s« consigo e quer adicionar:",
    "»%s« added a note to a file shared with you" : "»%s« adicionou uma nota a um ficheiro partilhado consigo",
    "Open »%s«" : "Abrir »%s«",
    "%1$s via %2$s" : "%1$s via %2$s",
    "You are not allowed to share %s" : "Não está autorizado a partilhar %s",
    "Can’t increase permissions of %s" : "Não é possível aumentar as permissões de %s",
    "Files can’t be shared with delete permissions" : "Ficheiros não podem ser partilhados com permissões de apagar",
    "Files can’t be shared with create permissions" : "Ficheiros não podem ser partilhados com permissões de criação",
    "Expiration date is in the past" : "A data de expiração está no passado",
    "Can’t set expiration date more than %s days in the future" : "Não é possível definir data de expiração a mais de %s dias no futuro",
    "%1$s shared »%2$s« with you" : "%1$s partilhado »%2$s« contigo",
    "%1$s shared »%2$s« with you." : "%1$s partilhado »%2$s« contigo.",
    "Click the button below to open it." : "Clicar no botão abaixo para abrir.",
    "The requested share does not exist anymore" : "A partilha requisitada já não existe",
    "Could not find category \"%s\"" : "Não foi encontrado a categoria \"%s\"",
    "Sunday" : "Domingo",
    "Monday" : "Segunda-feira",
    "Tuesday" : "Terça-feira",
    "Wednesday" : "Quarta-feira",
    "Thursday" : "Quinta-feira",
    "Friday" : "Sexta-feira",
    "Saturday" : "Sábado",
    "Sun." : "Dom.",
    "Mon." : "Seg.",
    "Tue." : "Ter.",
    "Wed." : "Qua.",
    "Thu." : "Qui.",
    "Fri." : "Sex.",
    "Sat." : "Sáb.",
    "Su" : "Dom",
    "Mo" : "Seg",
    "Tu" : "Ter",
    "We" : "Qua",
    "Th" : "Qui",
    "Fr" : "Sex",
    "Sa" : "Sáb",
    "January" : "Janeiro",
    "February" : "Fevereiro",
    "March" : "Março",
    "April" : "Abril",
    "May" : "Maio",
    "June" : "Junho",
    "July" : "Julho",
    "August" : "Agosto",
    "September" : "Setembro",
    "October" : "Outubro",
    "November" : "Novembro",
    "December" : "Dezembro",
    "Jan." : "Jan.",
    "Feb." : "Fev.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ago.",
    "Sep." : "Set.",
    "Oct." : "Out.",
    "Nov." : "Nov.",
    "Dec." : "Dez.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Apenas os seguintes caracteres são permitidos num nome de utilizador: \"a-z\", \"A-Z\", \"0-9\", e \"_.@-'\"",
    "A valid username must be provided" : "Um nome de utilizador válido deve ser fornecido",
    "Username contains whitespace at the beginning or at the end" : "Nome de utilizador contém espaço em branco no início ou no fim",
    "Username must not consist of dots only" : "O utilizador não pode consistir de apenas pontos",
    "A valid password must be provided" : "Deve ser fornecida uma palavra-passe válida",
    "The username is already being used" : "O nome de utilizador já está a ser usado",
    "Could not create user" : "Não foi possível criar o utilizador",
    "User disabled" : "Utilizador desativado",
    "Login canceled by app" : "Sessão cancelada pela app",
    "a safe home for all your data" : "Um lugar seguro para todos os seus dados",
    "File is currently busy, please try again later" : "O ficheiro está ocupado, por favor, tente mais tarde",
    "Can't read file" : "Não é possível ler o ficheiro",
    "Application is not enabled" : "A aplicação não está activada",
    "Authentication error" : "Erro na autenticação",
    "Token expired. Please reload page." : "O token expirou. Por favor recarregue a página.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nenhuma base de dados de drivers (sqlite, mysql, or postgresql) instaladas.",
    "Cannot write into \"config\" directory" : "Não é possível escrever na directoria \"configurar\"",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Isto pode geralmente ser corrigido ao adicionar permissões de escrita à pasta de configuração ao servidor web. Ver %s.",
    "Cannot write into \"apps\" directory" : "Não é possivel escrever na directoria \"aplicações\"",
    "Cannot create \"data\" directory" : "Não é possivel criar a directoria \"data\"",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Isto pode geralmente ser corrigido ao adicionar permissões de escrita à pasta de raiz. Ver %s",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "As permissões podem geralmente ser corrigidas dando ao servidor web permissões de escrita na pasta de raiz. Ver %s.",
    "Setting locale to %s failed" : "Definindo local para %s falhado",
    "Please install one of these locales on your system and restart your webserver." : "Por favor instale um destes locais no seu sistema e reinicie o seu servidor web.",
    "Please ask your server administrator to install the module." : "Por favor pergunte ao seu administrador do servidor para instalar o modulo.",
    "PHP module %s not installed." : "O modulo %s PHP não está instalado.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Configuração PHP \"%s\" não está definida para \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajustar esta definição no php.ini fará com que o Nextcloud inicie novamente",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está configurado para \"%s\" invés do valor habitual de \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para corrigir este problema altere o <code>mbstring.func_overload</code> para <code>0</code> no seu php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Necessária pelo menos libxml2 2.7.0. Atualmente %s está instalada.",
    "To fix this issue update your libxml2 version and restart your web server." : "Para corrigir este problema actualize a versão da libxml2 e reinicie o seu servidor web.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP está aparentemente configurado a remover blocos doc em linha. Isto vai tornar algumas aplicações básicas inacessíveis.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isto é provavelmente causado por uma cache/acelerador como o Zend OPcache or eAcelerador.",
    "PHP modules have been installed, but they are still listed as missing?" : "Os módulos PHP foram instalados,   mas eles ainda estão listados como desaparecidos?",
    "Please ask your server administrator to restart the web server." : "Pro favor pergunte ao seu administrador do servidor para reiniciar o servidor da internet.",
    "PostgreSQL >= 9 required" : "Necessita PostgreSQL >= 9",
    "Please upgrade your database version" : "Por favor actualize a sua versão da base de dados",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor altere as permissões para 0770 para que esse directório não possa ser listado por outros utilizadores.",
    "Your data directory is readable by other users" : "O seu directório de dados é legível por outros utilizadores",
    "Your data directory must be an absolute path" : "O seu directório de dados deve ser um caminho absoluto",
    "Check the value of \"datadirectory\" in your configuration" : "Verifique o valor de \"datadirectory\" na sua configuração",
    "Your data directory is invalid" : "O seu directório de dados é inválido",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Garanta que existe um ficheiro chamado \".occdata\" na raiz do directório de dados",
    "Could not obtain lock type %d on \"%s\"." : "Não foi possível obter o tipo de bloqueio %d em \"%s\".",
    "Storage unauthorized. %s" : "Armazenamento desautorizado. %s",
    "Storage incomplete configuration. %s" : "Configuração incompleta do armazenamento. %s",
    "Storage connection error. %s" : "Erro de ligação ao armazenamento. %s",
    "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
    "Storage connection timeout. %s" : "Tempo de ligação ao armazenamento expirou. %s",
    "Create" : "Criar",
    "Delete" : "Apagar",
    "Share" : "Partilhar",
    "Basic settings" : "Definições básicas",
    "Sharing" : "Partilhar",
    "Security" : "Segurança",
    "Personal info" : "Informação pessoal",
    "Unlimited" : "Ilimitado",
    "Verifying" : "A verificar",
    "Verifying …" : "A verificar...",
    "Verify" : "Verificar",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "A partilha de %s falhou porque a interface não permite as partilhas do tipo %i",
    "Sharing %s failed, because the file does not exist" : "A partilha de %s falhou, porque o ficheiro não existe",
    "Sharing %s failed, because you can not share with yourself" : "A partilha de %s falhou, porque não é possível partilhar consigo mesmo",
    "You need to provide a password to create a public link, only protected links are allowed" : "Precisa de fornecer uma palavra-passe para criar uma hiperligação publica, só são permitidas hiperligações protegidas",
    "Sharing %s failed, because sharing with links is not allowed" : "A partilha de %s falhou, porque partilhar com links não é permitido",
    "Not allowed to create a federated share with the same user" : "Não é possível criar uma partilha federada com o mesmo utilizador",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Não é possível definir data de expiração. As partilhas não podem expirar mais de %s depois de terem sido partilhadas",
    "Cannot set expiration date. Expiration date is in the past" : "Não é possivel definir data de expiração. A data de expiração está no passado",
    "Sharing failed, because the user %s is the original sharer" : "A partilha falhou, porque o utilizador %s é o distribuidor original",
    "Sharing %s failed, because resharing is not allowed" : "A partilha %s falhou, porque repartilhar não é permitido",
    "Sharing %s failed, because the file could not be found in the file cache" : "A partilha %s falhou, devido ao ficheiro não poder ser encontrado na cache de ficheiros",
    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Isto pode ser normalmente resolvido dando ao servidor web direito de escrita para o directório de aplicação ou desactivando a loja de aplicações no ficheiro de configuração. Ver %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.12.tar.bz2: nextcloud/lib/l10n/pt_PT.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Não é possível gravar no diretório \"config\"!",
    "See %s" : "Ver %s",
    "Sample configuration detected" : "Detetado exemplo de configuração",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Foi detetado que a configuração de amostra foi copiada. Isso pode danificar a sua instalação e não é suportado. Por favor, leia a documentação antes de realizar mudanças no config.php",
    "The page could not be found on the server." : "Esta página não foi encontrada no servidor.",
    "Email verification" : "Verificação de e-mail",
    "Click the following button to confirm your email." : "Clique no botão a seguir para confirmar o seu e-mail.",
    "Click the following link to confirm your email." : "Clique na hiperligação a seguir para confirmar o seu e-mail.",
    "Confirm your email" : "Confirmar o seu e-mail",
    "Other activities" : "Outras atividades",
    "%1$s and %2$s" : "%1$s e %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s e %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s e %5$s",
    "Enterprise bundle" : "Pacote Empresa",
    "Groupware bundle" : "Pacote Colaborativo",
    "Social sharing bundle" : "Pacote Partilha Social",
    "PHP %s or higher is required." : "Necessário PHP %s ou superior.",
    "PHP with a version lower than %s is required." : "É necessário um PHP com uma versão inferir a %s.",
    "%sbit or higher PHP required." : "Necessário PHP %sbit ou superior.",
    "The following architectures are supported: %s" : "As seguintes arquiteturas são suportadas: %s",
    "The following databases are supported: %s" : "As seguintes bases de dados são suportadas: %s",
    "The command line tool %s could not be found" : "Não foi encontrada a ferramenta de linha de comando %s",
    "The library %s is not available." : "A biblioteca %s não está disponível.",
    "The following platforms are supported: %s" : "As seguintes plataformas são suportadas: %s",
    "Server version %s or higher is required." : "É necessária versão do servidor %s or superior. ",
    "Server version %s or lower is required." : "É necessária versão do servidor %s or inferior.",
    "Authentication" : "Autenticação",
    "Unknown filetype" : "Tipo de ficheiro desconhecido",
    "Invalid image" : "Imagem inválida",
    "Avatar image is not square" : "A imagem do avatar não é quadrada.",
    "Files" : "Ficheiros",
    "View profile" : "Visualizar perfil",
    "today" : "hoje",
    "tomorrow" : "Amanhã",
    "yesterday" : "ontem",
    "_in %n day_::_in %n days_" : ["em %n dia","em %n dias","em %n dias"],
    "_%n day ago_::_%n days ago_" : ["%n dia atrás","%n dias atrás","%n dias atrás"],
    "next month" : "Próximo mês",
    "last month" : "ultimo mês",
    "_in %n month_::_in %n months_" : ["em %n mês","em %n meses","em %n meses"],
    "_%n month ago_::_%n months ago_" : ["%n mês atrás","%n meses atrás","%n meses atrás"],
    "next year" : "Próximo ano",
    "last year" : "ano passado",
    "_in %n year_::_in %n years_" : ["dentro de%n ano","dentro de %n anos","dentro de %n anos"],
    "_%n year ago_::_%n years ago_" : ["%n ano atrás","%n anos atrás","%n anos atrás"],
    "_in %n hour_::_in %n hours_" : ["dentro de %n hora","dentro de %n horas","dentro de %n horas"],
    "_%n hour ago_::_%n hours ago_" : ["%n hora atrás","%n horas atrás","%n horas atrás"],
    "_in %n minute_::_in %n minutes_" : ["dentro de %n minuto","dentro de %n minutos","dentro de %n minutos"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minuto atrás","%n minutos atrás","%n minutos atrás"],
    "in a few seconds" : "em breves segundos",
    "seconds ago" : "Minutos atrás",
    "Empty file" : "Ficheiro vazio",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Módulo com ID: %s não existe. Por favor ative-o nas definições da aplicação ou contacte o administrador.",
    "Dot files are not allowed" : "Ficheiros dot não são permitidos",
    "File already exists" : "O ficheiro já existe",
    "Invalid path" : "Caminho inválido!",
    "Failed to create file from template" : "Erro ao criar o ficheiro a partir do modelo",
    "Templates" : "Modelos",
    "Filename contains at least one invalid character" : "Nome ficheiro contém pelo menos um carácter inválido",
    "Empty filename is not allowed" : "Não é permitido um ficheiro sem nome",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "A app \"%s\" não pode ser instalada porque o ficheiro appinfo não pode ser lido.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "A aplicação \"%s\" não pode ser instada porque não é compatível com esta versão do servidor.",
    "__language_name__" : "Português",
    "This is an automatically sent email, please do not reply." : "Este e-mail foi enviado automaticamente, por favor não responda a este e-mail.",
    "Apps" : "Apps",
    "Settings" : "Definições",
    "Log out" : "Sair",
    "Email" : "E-mail",
    "Mail %s" : "Mensagem para %s",
    "Phone" : "Telefone",
    "Call %s" : "Ligar a %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Visualizar %s no Twitter",
    "Website" : "Website",
    "Visit %s" : "Visite %s",
    "Address" : "Endereço",
    "Profile picture" : "Imagem do perfil",
    "About" : "Sobre",
    "Display name" : "Nome a exibir",
    "Headline" : "Título ",
    "Organisation" : "Organização",
    "Role" : "Função",
    "Additional settings" : "Definições adicionais",
    "You need to enter details of an existing account." : "Precisa de introduzir detalhes de uma conta existente.",
    "Oracle connection could not be established" : "Não foi possível estabelecer a ligação Oracle",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Esta plataforma não suporta o sistema operativo Mac OS X e o %s poderá não funcionar corretamente. Utilize por sua conta e risco.",
    "For the best results, please consider using a GNU/Linux server instead." : "Para um melhor resultado, utilize antes o servidor GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Parece que a instância %s está a ser executada num ambiente PHP de 32-bits e o open_basedir foi configurado no php.ini. Isto levará a problemas com ficheiros de tamanho superior a 4 GB e é altamente desencorajado.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, remova a definição open_basedir do seu php.ini ou altere o seu PHP para 64-bits.",
    "Set an admin password." : "Definia uma palavra-passe de administrador.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Ao partilhar a interface %s deve implementar a interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "Não foi encontrada a partilha da interface %s",
    "Sharing backend for %s not found" : "Não foi encontrada a partilha da interface para %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Unknown share type" : "Tipo de partilha desconhecido",
    "You are not allowed to share %s" : "Não está autorizado a partilhar %s",
    "Cannot increase permissions of %s" : "Não é possível aumentar as permissões de %s",
    "Expiration date is in the past" : "A data de expiração está no passado",
    "The requested share does not exist anymore" : "A partilha requisitada já não existe",
    "Could not find category \"%s\"" : "Não foi encontrado a categoria \"%s\"",
    "Sunday" : "Domingo",
    "Monday" : "Segunda-feira",
    "Tuesday" : "Terça-feira",
    "Wednesday" : "Quarta-feira",
    "Thursday" : "Quinta-feira",
    "Friday" : "Sexta-feira",
    "Saturday" : "Sábado",
    "Sun." : "Dom.",
    "Mon." : "Seg.",
    "Tue." : "Ter.",
    "Wed." : "Qua.",
    "Thu." : "Qui.",
    "Fri." : "Sex.",
    "Sat." : "Sáb.",
    "Su" : "Dom",
    "Mo" : "Seg",
    "Tu" : "Ter",
    "We" : "Qua",
    "Th" : "Qui",
    "Fr" : "Sex",
    "Sa" : "Sáb",
    "January" : "Janeiro",
    "February" : "Fevereiro",
    "March" : "Março",
    "April" : "Abril",
    "May" : "Maio",
    "June" : "Junho",
    "July" : "Julho",
    "August" : "Agosto",
    "September" : "Setembro",
    "October" : "Outubro",
    "November" : "Novembro",
    "December" : "Dezembro",
    "Jan." : "Jan.",
    "Feb." : "Fev.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ago.",
    "Sep." : "Set.",
    "Oct." : "Out.",
    "Nov." : "Nov.",
    "Dec." : "Dez.",
    "A valid password must be provided" : "Deve ser fornecida uma palavra-passe válida",
    "Login canceled by app" : "Sessão cancelada pela app",
    "a safe home for all your data" : "Um lugar seguro para todos os seus dados",
    "Application is not enabled" : "A aplicação não está ativada",
    "Authentication error" : "Erro na autenticação",
    "Token expired. Please reload page." : "O token expirou. Por favor recarregue a página.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nenhuma base de dados de drivers (sqlite, mysql, or postgresql) instaladas.",
    "Cannot write into \"config\" directory." : "Não é possível escrever na diretoria \"config\".",
    "Your data directory is not writable." : "A sua diretoria de dados é só de leitura.",
    "PHP module %s not installed." : "O modulo %s PHP não está instalado.",
    "Please ask your server administrator to install the module." : "Por favor pergunte ao seu administrador do servidor para instalar o modulo.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Configuração PHP \"%s\" não está definida para \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajustar esta definição no php.ini fará com que o Nextcloud inicie novamente",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP está aparentemente configurado a remover blocos doc em linha. Isto vai tornar algumas aplicações básicas inacessíveis.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isto é provavelmente causado por uma cache/acelerador como o Zend OPcache or eAcelerador.",
    "PHP modules have been installed, but they are still listed as missing?" : "Os módulos PHP foram instalados,   mas eles ainda estão listados como desaparecidos?",
    "Please ask your server administrator to restart the web server." : "Pro favor pergunte ao seu administrador do servidor para reiniciar o servidor da internet.",
    "Your data directory is invalid." : "A sua diretoria de dados é inválida.",
    "Action \"%s\" not supported or implemented." : "Ação \"%s\" não suportada ou implementada.",
    "Could not obtain lock type %d on \"%s\"." : "Não foi possível obter o tipo de bloqueio %d em \"%s\".",
    "Storage unauthorized. %s" : "Armazenamento desautorizado. %s",
    "Storage incomplete configuration. %s" : "Configuração incompleta do armazenamento. %s",
    "Storage connection error. %s" : "Erro de ligação ao armazenamento. %s",
    "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
    "Storage connection timeout. %s" : "A ligação ao armazenamento expirou. %s",
    "Chat" : "Chat",
    "Text" : "Texto",
    "Summary" : "Resumo",
    "Translate" : "Traduzir",
    "Education Edition" : "Edição Educação",
    "File name is a reserved word" : "Nome de ficheiro é uma palavra reservada",
    "File name contains at least one invalid character" : "Nome de ficheiro contém pelo menos um caráter inválido",
    "File name is too long" : "Nome do ficheiro demasiado longo",
    "Users" : "Utilizadores",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s partilhado »%2$s« consigo e quer adicionar:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s partilhado »%2$s« consigo e quer adicionar:",
    "»%s« added a note to a file shared with you" : "»%s« adicionou uma nota a um ficheiro partilhado consigo",
    "Open »%s«" : "Abrir »%s«",
    "%1$s shared »%2$s« with you" : "%1$s partilhado »%2$s« contigo",
    "%1$s shared »%2$s« with you." : "%1$s partilhado »%2$s« contigo.",
    "Click the button below to open it." : "Clicar no botão abaixo para abrir.",
    "File is currently busy, please try again later" : "O ficheiro está ocupado, por favor, tente mais tarde",
    "Cannot download file" : "Não é possível transferir o ficheiro",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Garanta que existe um ficheiro chamado \".occdata\" na raiz do diretório de dados"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
